Triangulation

Struct Triangulation 

pub struct Triangulation<'a, V: IndexType> { /* private fields */ }
A triangulation of a polygon. Will borrow the index buffer and append new triangles to it. Most methods will only look at the indices that are added after the borrow startet. It’s fine to add triangles to the index buffer directly while it is borrowed.

Implementations

Source

impl<'a, V: IndexType> Triangulation<'a, V>

pub fn new(indices: &'a mut Vec<V>) -> Self

Create a new triangulation

pub fn insert_triangle(&mut self, a: V, b: V, c: V)

Insert a triangle into the triangulation using global indices

pub fn get_index(&self, i: usize) -> V

Get the ith index that was added to the triangulation

pub fn get_triangle(&self, i: usize) -> (V, V, V)

Get a triangle from the triangulation using the number of the triangle in the triangulation

pub fn get_triangle_area<Vec2: Vector2D>( &self, i: usize, vec_hm: &HashMap<V, Vec2>, ) -> Vec2::S

Get the area of a triangle in the triangulation

pub fn insert_triangle_local<Vec2: Vector2D>( &mut self, a: usize, b: usize, c: usize, vec2s: &Vec<IndexedVertex2D<V, Vec2>>, )

Insert a triangle into the triangulation using local indices

pub fn map_indices(&mut self, id_map: &HashMap<V, V>)

Map the indices in the triangulation using a hashmap

pub fn len(&self) -> usize

Get the number of triangles inserted into the index buffer since the triangulation was created

pub fn next_pos(&self) -> usize

Get the next index that will be added to the index buffer

pub fn flip_edge( &mut self, a: V, b: V, triangle_ab: usize, triangle_ba: usize, ) -> Result<(), ()>

Flip the edge of the two triangles

pub fn verify_non_degenerate_triangle<Vec2: Vector2D>( &self, vec_hm: &HashMap<V, Vec2>, )

Check for non-degenerate triangles (no zero-area triangles)

pub fn verify_indices<Vec2: Vector2D>(&self, vec_hm: &HashMap<V, Vec2>)

Check for valid indices (i.e., they should be within the bounds of the vertices)

pub fn verify_no_intersections<Vec2: Vector2D>(&self, vec_hm: &HashMap<V, Vec2>)

Check that no two triangles have intersecting edges

pub fn get_area<Vec2: Vector2D>(&self, vec_hm: &HashMap<V, Vec2>) -> Vec2::S

Sum the area of all triangles added to the index buffer since the triangulation was created

pub fn total_edge_weight<Vec2: Vector2D>( &self, vec_hm: &HashMap<V, Vec2>, ) -> Vec2::S

Calculate the total edge weight of the triangulation

pub fn verify_area<Vec2: Vector2D, Poly: Polygon<Vec2>>( &self, vec2s: &Vec<IndexedVertex2D<V, Vec2>>, vec_hm: &HashMap<V, Vec2>, )

Calculate the area of the polygon and check if it is the same as the sum of the areas of the triangles

pub fn verify_all_indices_used<Vec2: Vector2D>( &self, vec2s: &Vec<IndexedVertex2D<V, Vec2>>, )

Check that the set of used indices exactly matches the set of indices in the triangulation

pub fn verify_full<Vec2: Vector2D, Poly: Polygon<Vec2>>( &self, vec2s: &Vec<IndexedVertex2D<V, Vec2>>, )

Runs a large number of tests on the triangulation to verify that it is well-formed