pub struct DynamicMonoTriangulator<V: IndexType, Vec2: Vector2D, Poly: Polygon<Vec2>> { /* private fields */ }Expand description
A variant of the sweep-line algorithm that finds the min-weight triangulation for each monotone sub-polygon using dynamic programming, leading to an overall O(n^2) time complexity.
When using the bound k, the approximation quality decreases the smaller k is, with time O(k^2 n log n). However, for k << n this comes in most cases very quickly close to O(n log n).
For the quality of the approximation it is generally beneficial to rotate the mesh such that the mesh can be decomposed in a large number of y-monotone components.